#!/usr/bin/env python
#
# This file is part of Baseball Math
# Author(s): Elizabeth Amador and Marisela Rebollar, Girlstart
# Copyright 2008
#
# Source code is derived from Girlstart's Project IT Girl Game Templates:
# http://itgirl.dreamhosters.com/itgirlgames/, http://www.girlstart.org/itgirl
# See the credits file for image sources.
#
# Baseball Math is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Baseball Math is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Baseball Math.  If not, see <http://www.gnu.org/licenses/>.

import pygame, random, string
from helpers import *

class ActivityGenerator(pygame.sprite.Sprite):
	def __init__(self,background_image):
		pygame.sprite.Sprite.__init__(self)
		self.screen = pygame.display.get_surface()
		self.area = self.screen.get_rect()
		self.background = background_image
		
		self.score = 0
		self.strikes = 0
		self.activity_count = 0
		self.correct_answer_count = 0

	def good_effect(self):
		self.score = self.score + 1
		display_static_image('good_effect.gif',1,self.screen,self.background,self.area)

	def bad_effect(self):
		display_static_image('tryingII.gif',1,self.screen,self.background,self.area)
		self.strikes = self.strikes +1
		
	def ask_addition_question(self,number1,number2,correct_answer):
		answered_correctly = False
		activity_completed = False

		user_answer = ""
		
		while not activity_completed:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					if event.key == K_RETURN:
						activity_completed = True
						answered_correctly = (string.lower(user_answer) == string.lower(str(correct_answer)))
					elif event.key == K_BACKSPACE:
						user_answer = user_answer[0:-1]
					elif event.key in range(256):
						user_answer += chr(event.key)
			
			# Draw everything to the screen
			self.screen.blit(self.background, (0, 0))
			
			# Draw the scoreboard
			font = pygame.font.Font(None, 100)
			text = font.render("Score: " + str(self.score), 1, (255,69,0))
			textrect = text.get_rect()
			textrect.left, textrect.top = 0,0
			self.screen.blit(text, textrect)

			# Draw the problem
			font = pygame.font.Font(None, 30)
			text = font.render(str(number1), 1, (0,0,0))
			textrect = text.get_rect()
			textrect.top = 200
			textrect.right = 420
			self.screen.blit(text, textrect)
			
			text = font.render(str(number2), 1, (0,0,0))
			textrect = text.get_rect()
			textrect.top = 225
			textrect.right = 420
			self.screen.blit(text, textrect)

			text = font.render("+", 1, (255,69,0))
			textrect = text.get_rect()
			textrect.top = 225
			textrect.left = 390
			self.screen.blit(text, textrect)

			text = font.render("_____", 1, (0,0,0))
			textrect = text.get_rect()
			textrect.top = 230
			textrect.right = 445
			self.screen.blit(text, textrect)

			# Give instructions for submitting the answer
			font = pygame.font.Font(None, 30)
			text = font.render("Press Enter to submit your answer.", 1, (255,69,0))
			textrect = text.get_rect()
			textrect.centerx = self.area.centerx
			textrect.bottom = self.area.bottom - 100
			self.screen.blit(text, textrect)

			# Draw the user's input
			font = pygame.font.Font(None, 30)
			text = font.render(user_answer, 1, (0,0,0))
			textrect = text.get_rect()
			textrect.top = 255
			textrect.right = 420
			self.screen.blit(text, textrect)
			
			pygame.display.flip()

		return answered_correctly
	
	def play(self,correct_answer):
		#default play will ask the user to press a specific key to complete the activity
		answered_correctly = False
		activity_completed = False
		
		while not activity_completed:
			for event in pygame.event.get():
				if event.type == pygame.QUIT:
					sys.exit()
				elif event.type == pygame.KEYDOWN:
					activity_completed = True
					if event.key == ord(chr(correct_answer)):
						answered_correctly = True
		
			# Draw everything to the screen
			self.screen.blit(self.background, (0, 0))

			font = pygame.font.Font(None, 30)
			text = font.render("6+2", 1, (255,69,0))
			textrect = text.get_rect()
			textrect.centerx, textrect.centery = self.area.centerx,self.area.centery
			self.screen.blit(text, textrect)
			
			pygame.display.flip()

		self.activity_count += 1
		if answered_correctly:
			self.correct_answer_count += 1
		return answered_correctly

	def generate_activity(self):
		numberone=random.randint(1,9)
		numbertwo=random.randint(1,9)
		if self.ask_addition_question(numberone, numbertwo, numberone+numbertwo):
			self.good_effect()
		else:
			self.bad_effect()
